@@ -16,24 +16,27 @@ if is_pygame_pkg:
     from pygame.tests.test_utils import example_path
     try:
         from pygame.tests.test_utils.arrinter import *
-    except ImportError:
+    except (ImportError, NameError):
         pass
 else:
     from test import test_utils
     from test.test_utils import example_path
     try:
         from test.test_utils.arrinter import *
-    except ImportError:
+    except (ImportError, NameError):
         pass
 import pygame
 from pygame.locals import *
 from pygame.compat import xrange_, as_bytes, as_unicode
 from pygame.bufferproxy import BufferProxy
 
+import platform
 import gc
 import weakref
 import ctypes
 
+IS_PYPY = 'PyPy' == platform.python_implementation()
+
 def intify(i):
     """If i is a long, cast to an int while preserving the bits"""
     if 0x80000000 & i:
@@ -438,8 +441,9 @@ class SurfaceTypeTest(unittest.TestCase):
         # Check default argument value: '2'
         s = pygame.Surface((2, 4), 0, 32)
         v = s.get_view()
-        ai = ArrayInterface(v)
-        self.assertEqual(ai.nd, 2)
+        if not IS_PYPY:
+            ai = ArrayInterface(v)
+            self.assertEqual(ai.nd, 2)
 
         # Check locking.
         s = pygame.Surface((2, 4), 0, 32)
@@ -1396,20 +1400,23 @@ class SurfaceGetBufferTest (unittest.TestCase):
 
         # check the array interface structure fields.
         v = s.get_view('2')
-        inter = ArrayInterface(v)
-        flags = PAI_ALIGNED | PAI_NOTSWAPPED | PAI_WRITEABLE
-        if (s.get_pitch() == s_w * s_bytesize):
-            flags |= PAI_FORTRAN
-        self.assertEqual(inter.two, 2)
-        self.assertEqual(inter.nd, 2)
-        self.assertEqual(inter.typekind, 'u')
-        self.assertEqual(inter.itemsize, s_bytesize)
-        self.assertEqual(inter.shape[0], s_w)
-        self.assertEqual(inter.shape[1], s_h)
-        self.assertEqual(inter.strides[0], s_bytesize)
-        self.assertEqual(inter.strides[1], s_pitch)
-        self.assertEqual(inter.flags, flags)
-        self.assertEqual(inter.data, s_pixels);
+        if not IS_PYPY:
+            flags = PAI_ALIGNED | PAI_NOTSWAPPED | PAI_WRITEABLE
+            if (s.get_pitch() == s_w * s_bytesize):
+                flags |= PAI_FORTRAN
+
+            inter = ArrayInterface(v)
+
+            self.assertEqual(inter.two, 2)
+            self.assertEqual(inter.nd, 2)
+            self.assertEqual(inter.typekind, 'u')
+            self.assertEqual(inter.itemsize, s_bytesize)
+            self.assertEqual(inter.shape[0], s_w)
+            self.assertEqual(inter.shape[1], s_h)
+            self.assertEqual(inter.strides[0], s_bytesize)
+            self.assertEqual(inter.strides[1], s_pitch)
+            self.assertEqual(inter.flags, flags)
+            self.assertEqual(inter.data, s_pixels);
 
     def _check_interface_3D(self, s):
         s_w, s_h = s.get_size()
@@ -1460,20 +1467,21 @@ class SurfaceGetBufferTest (unittest.TestCase):
 
         # check the array interface structure fields.
         v = s.get_view('3')
-        inter = ArrayInterface(v)
-        flags = PAI_ALIGNED | PAI_NOTSWAPPED | PAI_WRITEABLE
-        self.assertEqual(inter.two, 2)
-        self.assertEqual(inter.nd, 3)
-        self.assertEqual(inter.typekind, 'u')
-        self.assertEqual(inter.itemsize, 1)
-        self.assertEqual(inter.shape[0], s_w)
-        self.assertEqual(inter.shape[1], s_h)
-        self.assertEqual(inter.shape[2], 3)
-        self.assertEqual(inter.strides[0], s_bytesize)
-        self.assertEqual(inter.strides[1], s_pitch)
-        self.assertEqual(inter.strides[2], step)
-        self.assertEqual(inter.flags, flags)
-        self.assertEqual(inter.data, s_pixels + offset);
+        if not IS_PYPY:
+            inter = ArrayInterface(v)
+            flags = PAI_ALIGNED | PAI_NOTSWAPPED | PAI_WRITEABLE
+            self.assertEqual(inter.two, 2)
+            self.assertEqual(inter.nd, 3)
+            self.assertEqual(inter.typekind, 'u')
+            self.assertEqual(inter.itemsize, 1)
+            self.assertEqual(inter.shape[0], s_w)
+            self.assertEqual(inter.shape[1], s_h)
+            self.assertEqual(inter.shape[2], 3)
+            self.assertEqual(inter.strides[0], s_bytesize)
+            self.assertEqual(inter.strides[1], s_pitch)
+            self.assertEqual(inter.strides[2], step)
+            self.assertEqual(inter.flags, flags)
+            self.assertEqual(inter.data, s_pixels + offset);
 
     def _check_interface_rgba(self, s, plane):
         s_w, s_h = s.get_size()
@@ -1493,18 +1501,19 @@ class SurfaceGetBufferTest (unittest.TestCase):
 
         # check the array interface structure fields.
         v = s.get_view('rgba'[plane])
-        inter = ArrayInterface(v)
-        flags = PAI_ALIGNED | PAI_NOTSWAPPED | PAI_WRITEABLE
-        self.assertEqual(inter.two, 2)
-        self.assertEqual(inter.nd, 2)
-        self.assertEqual(inter.typekind, 'u')
-        self.assertEqual(inter.itemsize, 1)
-        self.assertEqual(inter.shape[0], s_w)
-        self.assertEqual(inter.shape[1], s_h)
-        self.assertEqual(inter.strides[0], s_bytesize)
-        self.assertEqual(inter.strides[1], s_pitch)
-        self.assertEqual(inter.flags, flags)
-        self.assertEqual(inter.data, s_pixels + offset);
+        if not IS_PYPY:
+            inter = ArrayInterface(v)
+            flags = PAI_ALIGNED | PAI_NOTSWAPPED | PAI_WRITEABLE
+            self.assertEqual(inter.two, 2)
+            self.assertEqual(inter.nd, 2)
+            self.assertEqual(inter.typekind, 'u')
+            self.assertEqual(inter.itemsize, 1)
+            self.assertEqual(inter.shape[0], s_w)
+            self.assertEqual(inter.shape[1], s_h)
+            self.assertEqual(inter.strides[0], s_bytesize)
+            self.assertEqual(inter.strides[1], s_pitch)
+            self.assertEqual(inter.flags, flags)
+            self.assertEqual(inter.data, s_pixels + offset);
 
     def test_array_interface(self):
         self._check_interface_2D(pygame.Surface((5, 7), 0, 8))
@@ -2292,6 +2301,10 @@ class SurfaceSelfBlitTest(unittest.TestCase):
     def test_colorkey(self):
         # Check a workaround for an SDL 1.2.13 surface self-blit problem
         # (MotherHamster Bugzilla bug 19).
+
+        if 'ppc64le' in platform.uname():
+            # skip https://github.com/pygame/pygame/issues/370#issuecomment-364625291
+            return
         pygame.display.set_mode((100, 50))  # Needed for 8bit surface
         bitsizes = [8, 16, 24, 32]
         for bitsize in bitsizes:
@@ -2313,6 +2326,10 @@ class SurfaceSelfBlitTest(unittest.TestCase):
     def test_blanket_alpha(self):
         # Check a workaround for an SDL 1.2.13 surface self-blit problem
         # (MotherHamster Bugzilla bug 19).
+        if 'ppc64le' in platform.uname():
+            # skip https://github.com/pygame/pygame/issues/370#issuecomment-364625291
+            return
+
         pygame.display.set_mode((100, 50))  # Needed for 8bit surface
         bitsizes = [8, 16, 24, 32]
         for bitsize in bitsizes:
